@@ -129,7 +129,7 @@ class MemberConverter(IDConverter):
     """
 
     async def query_member_named(self, guild, argument):
-        cache = guild._state._member_cache_flags.joined
+        cache = guild._state.member_cache_flags.joined
         if len(argument) > 5 and argument[-5] == '#':
             username, _, discriminator = argument.rpartition('#')
             members = await guild.query_members(username, limit=100, cache=cache)
@@ -140,7 +140,7 @@ class MemberConverter(IDConverter):
 
     async def query_member_by_id(self, bot, guild, user_id):
         ws = bot._get_websocket(shard_id=guild.shard_id)
-        cache = guild._state._member_cache_flags.joined
+        cache = guild._state.member_cache_flags.joined
         if ws.is_ratelimited():
             # If we're being rate limited on the WS, then fall back to using the HTTP API
             # So we don't have to wait ~60 seconds for the query to finish
@@ -206,6 +206,10 @@ class UserConverter(IDConverter):
 
     .. versionchanged:: 1.5
          Raise :exc:`.UserNotFound` instead of generic :exc:`.BadArgument`
+
+    .. versionchanged:: 1.6
+        This converter now lazily fetches users from the HTTP APIs if an ID is passed
+        and it's not available in cache.
     """
     async def convert(self, ctx, argument):
         match = self._get_id_match(argument) or re.match(r'<@!?([0-9]+)>$', argument)
@@ -214,26 +218,33 @@ class UserConverter(IDConverter):
 
         if match is not None:
             user_id = int(match.group(1))
-            result = await ctx.bot.try_user(user_id) or _utils_get(ctx.message.mentions, id=user_id)
-        else:
-            arg = argument
+            result = ctx.bot.get_user(user_id) or _utils_get(ctx.message.mentions, id=user_id)
+            if result is None:
+                try:
+                    result = await ctx.bot.try_user(user_id)
+                except discord.HTTPException:
+                    raise UserNotFound(argument) from None
 
-            # Remove the '@' character if this is the first character from the argument
-            if arg[0] == '@':
-                # Remove first character
-                arg = arg[1:]
+            return result
 
-            # check for discriminator if it exists,
-            if len(arg) > 5 and arg[-5] == '#':
-                discrim = arg[-4:]
-                name = arg[:-5]
-                predicate = lambda u: u.name == name and u.discriminator == discrim
-                result = discord.utils.find(predicate, state._users.values())
-                if result is not None:
-                    return result
+        arg = argument
 
-            predicate = lambda u: u.name == arg
+        # Remove the '@' character if this is the first character from the argument
+        if arg[0] == '@':
+            # Remove first character
+            arg = arg[1:]
+
+        # check for discriminator if it exists,
+        if len(arg) > 5 and arg[-5] == '#':
+            discrim = arg[-4:]
+            name = arg[:-5]
+            predicate = lambda u: u.name == name and u.discriminator == discrim
             result = discord.utils.find(predicate, state._users.values())
+            if result is not None:
+                return result
+
+        predicate = lambda u: u.name == arg
+        result = discord.utils.find(predicate, state._users.values())
 
         if result is None:
             raise UserNotFound(argument)
@@ -254,12 +265,11 @@ class MessageConverter(Converter):
     .. versionchanged:: 1.5
          Raise :exc:`.ChannelNotFound`, `MessageNotFound` or `ChannelNotReadable` instead of generic :exc:`.BadArgument`
     """
-
     async def convert(self, ctx, argument):
-        id_regex = re.compile(r'^(?:(?P<channel_id>[0-9]{15,21})-)?(?P<message_id>[0-9]{15,21})$')
+        id_regex = re.compile(r'(?:(?P<channel_id>[0-9]{15,21})-)?(?P<message_id>[0-9]{15,21})$')
         link_regex = re.compile(
-            r'^https?://(?:(ptb|canary)\.)?discord(?:app)?\.com/channels/'
-            r'(?:([0-9]{15,21})|(@me))'
+            r'https?://(?:(ptb|canary|www)\.)?discord(?:app)?\.com/channels/'
+            r'(?:[0-9]{15,21}|@me)'
             r'/(?P<channel_id>[0-9]{15,21})/(?P<message_id>[0-9]{15,21})/?$'
         )
         match = id_regex.match(argument) or link_regex.match(argument)
